@@ -11,6 +11,48 @@ from ... import customer as lib_customer
 from . import api
 
 
+@api.route('/customers/defup/<string:uuid>', methods=['POST'])
+def defup_customers(uuid):
+    """
+    defupé un client
+    ---
+    tags:
+      - Customers
+    responses:
+      200:
+        description: operation reussit
+        $ref: "#/definitions/Informations
+      201:
+        description: deja defupé
+      204:
+        description: politique du client a changé
+      500:
+        description: Une erreur interne est survenue
+    """
+    try:
+        int(uuid)
+    except ValueError:
+        customer = lib_customer.Customer(uuid)
+    else:
+        search_customer = [
+            customer for customer in lib_customer.Customer.all()
+            if customer.refnum == uuid
+            ]
+        if search_customer:
+            customer = search_customer.pop()
+        else:  # aucun client n'a été trouvé
+            return not_found(
+                message="Le client {} n'existe pas".format(uuid),
+                code='{}-{}'.format(
+                    SERVICE_CODE,
+                    '4040'
+                    ),
+                service_code=SERVICE_CODE
+                )
+    response = customer.defup_from_aiguillier()
+    return jsonify(response)
+
+
 @api.route('/customers', methods=['GET'])
 def get_customers():
     """
